# global figure settings
source(file="predict_wrapper.R")
source(file="plotting.R")
source(file="settings.R")

library(cowplot)
library(scales)
library(ggdendro)
library(tidyverse)

FIG_PATH = 'figures/'
FIG_SI_PATH = paste(FIG_PATH, "si/", sep="")

mean_filt_rnaseq = 2
var_filt_rnaseq = 0.5
var_filt_rppa = 0.1

# prediction constants
method="pls"
Nrep = 1024
Nbg = 1024
Ncore = 4
remove_dups = F

# figure constants
clust_method = "complete"


drugs <- c('Cobimetinib', 'Irinotecan',  'Dabrafenib', 'DM1', 'Docetaxel', 'Doxorubicin', 'Apo2L', 'Apo2L+FlagM2', 'BRD6929', 'G02594618', 'G02594618+NA', 'AR00482666', 'Taselisib', 'GDC0575', 'GDC0994', 'Gemcitabine', 'GNE330', 'MMAE', 'Oligomycin', 'Paclitaxel', 'PD901', 'PNU159682', 'SG2507', 'SN34994', 'Trametinib', 'TrichostatinA', 'Vemurafenib')
drugs_gdc0068 = c("GDC0068", drugs)
drugtargets_simple <- c('MAPK', 'Chemo',  'MAPK', 'Chemo', 'Chemo', 'Chemo', 'Other', 'Other', 'HDAC', 'Other', 'Other', 'MAPK', 'PI3K', 'CHK1', 'MAPK', 'Chemo', 'CHK1', 'Chemo', 'Other', 'Chemo', 'MAPK', 'Chemo', 'Chemo', 'Chemo', 'MAPK', 'HDAC', 'MAPK')
drugtargets_simple_gdc0068 = c("AKT", drugtargets_simple)
drugtargets_simple <- ordered(drugtargets_simple,levels=c("MAPK","PI3K","Chemo","HDAC","CHK1","Other"))
drugtargets_simple_gdc0068 = ordered(drugtargets_simple_gdc0068, levels=c("AKT", "MAPK","PI3K","Chemo","HDAC","CHK1","Other"))


R2 = function(meas,preds) {
  notNA = !is.na(meas) & !is.na(preds)
  meas = meas[notNA]
  preds = preds[notNA]
  return(1-sum((meas-preds)^2)/sum((meas-mean(meas))^2))
}

str_wrap_factor <- function(x, ...) {
  levels(x) <- str_wrap(levels(x), ...)
  return(x)
}


# plot predictions
plot_pred = function(meas, preds, predplot=T, drug_show=T) {
  muts = getData(list(datasource='gt', datatype="mut", version="signature"))
  drug = colnames(meas)[1]
  
  mutfn = function(df) {
    braf = df$BRAF
    nras = df$NRAS
    notNA = !is.na(braf)
    ret = rep("Other", length(braf))
    ret[notNA][which(braf[notNA]==1)] = "BRAF V600E/K"
    ret[notNA][which(nras[notNA]==1)] = "NRAS"
    return(ret)
  }
  
  df = data.frame(meas=meas[,1,drop=F], preds=preds[,1,drop=F])
  colnames(df) = c("meas", "preds")
  df = left_join(df %>% mutate(CL=rownames(df)), muts %>% mutate(CL=rownames(muts)), by="CL") %>% 
    dplyr::select(-KRAS,-BRAFother) %>% 
    mutate(Mutation=mutfn(.)) %>% 
    dplyr::select(-BRAF,-NRAS)
  rownames(df) = df$CL
  df$CL = NULL
  
  df$Mutation = ordered(df$Mutation, levels=c("BRAF V600E/K", "NRAS", "Other"))
  
  if(predplot) {
    #R2lab = paste("R^2 == '", sprintf('%.2f',R2(meas, preds)),"'",sep="")
    rholab = paste("rho[s] == '", sprintf('%.2f',cor(meas, preds, use="complete.obs", method="spearman")),"'",sep="")
    #R2lab = paste("R^2 == ",sprintf('%.2f',round(0.40,2)),sep="")
  } else {
    #R2lab = paste("r^2 == '", sprintf('%.2f',cor(meas, preds, use="complete.obs")^2),"'",sep="")
    rholab = paste("rho[s] == '", sprintf('%.2f',cor(meas, preds, use="complete.obs", method="spearman")),"'",sep="")
  }
  
  minX <- min(meas,na.rm=TRUE)
  maxX <- max(meas,na.rm=TRUE)
  minY <- min(preds,na.rm=TRUE)
  maxY <- max(preds,na.rm=TRUE)
  if(max(preds, na.rm=T)/min(preds, na.rm=T)<1.1) {
    minY <- mean(preds,na.rm=TRUE)-0.6*(max(meas, na.rm=T)-min(meas, na.rm=T))
    maxY <- mean(preds,na.rm=TRUE)+0.4*(max(meas, na.rm=T)-min(meas, na.rm=T))
  }
  
  xlab = ifelse(predplot, "Measured AUC", paste(colnames(meas)[1], "AUC", sep=" "))
  ylab = ifelse(predplot, "Predicted AUC", paste(colnames(preds)[1], "AUC", sep=" "))
  
  ggpred = ggplot(df, aes(x=meas, y=preds)) +
    geom_point(aes(color=Mutation, shape=Mutation)) +
    xlab(xlab) +
    ylab(ylab) +
    theme(axis.title = element_text(size=size_axes_title),
          axis.text = element_text(size=size_axes_text), 
          legend.title = element_blank(),
          legend.text = element_text(size=size_axes_text),
          legend.key.size = unit(size_axes_text, "points"),
          #plot.margin = unit(c(0,0,0,0), "cm"),
          panel.background = element_rect(colour = "black", fill=NA, size=1, linetype="solid"))+
    scale_shape_manual(values=c("BRAF V600E/K"=16,"NRAS"=17,"Other"=15))+
    scale_color_manual(values=c("BRAF V600E/K"=colors()[29],"NRAS"=colors()[34],"Other"="green4"))+
    coord_cartesian(xlim=c(minX, maxX), ylim=c(minY,maxY))+
    annotate("text", x=minX+0.23*(maxX-minX),y=minY+0.9*(maxY-minY), label=rholab, parse=T, size=2.5)
  
  if(drug_show)
    ggpred = ggpred + 
      annotate("text", x=minX+0.75*(maxX-minX),y=minY+0.04*(maxY-minY), label=drug, size=2.5)
    
  #save_plot(filename="tmp.pdf", ggpred+theme(legend.position = "none"), base_width = 2, base_height = 2)
  
  return(ggpred)
  
}


#################################
######## FIGURE 1 ###############
#################################


# SIGNATURE MUTATIONS
###############################

muts = getData(list(datasource='gt', datatype="mut", version="signature"), remove_dups=remove_dups)
muts$WT = apply(muts,1, function(x) { if(sum(x)>0) return(0) else return(1) })
muts$CL = rownames(muts)
muts = muts %>% gather("Mutation", "Mutated",-CL) %>% 
  filter(Mutated>0)

muts$Mutation = ordered(muts$Mutation, levels=c("WT", "KRAS", "NRAS", "BRAFother", "BRAF"))
muts$CL = CL_pub_label(muts$CL)
CL_ordered = muts %>% group_by(CL) %>% summarise(MutScore = ifelse(length(Mutation)>1, min(as.numeric(Mutation))+0.5, max(as.numeric(Mutation)))) %>% arrange(MutScore) %>% dplyr::select(CL)
CL_ordered = data.frame(CL_ordered)$CL
muts$CL = ordered(muts$CL, levels = CL_ordered)


fig1a = ggplot(muts, aes(x=CL, y=Mutation))+
  geom_point(color="red", size=1.5)+
  scale_y_discrete(position="right", expand=c(0,0.5), labels=c("BRAF"="BRAF V600E/K", "BRAFother"="BRAF (other)", "NRAS"="NRAS G12/Q61", "KRAS"="KRAS mut", "WT"="WT RAS/RAF" ))+
  scale_x_discrete(expand=c(0,0.5))+
  theme(axis.text.x=element_text(angle=-90, vjust=0.5, hjust=0, size=size_axes_text),
        axis.text.y = element_text(size=size_axes_text),
        axis.title=element_blank(),
        axis.ticks = element_blank(),
        legend.position = "none",
        panel.background = element_rect(fill = "transparent", colour = NA),
        plot.background = element_rect(fill = "transparent", colour = NA),
        plot.margin = margin(l=0.7, t=0.5,r=0.3, unit="cm"))+
  geom_vline(xintercept=seq(0.5, length(muts$CL)-0.5, 1), 
             lwd=0.5, colour="black")+
  geom_hline(yintercept=seq(0.5, length(unique(muts$Mutation))+0.5, 1), 
             lwd=0.5, colour="black")


# AUC/IC50/MAXINH CARTOON
###############################

df_sen_cartoon = data.frame(x=c(0, 20, 40, 60, 80), y=c(100,93, 60, 35, 20))
fig1b_manual = ggplot(df_sen_cartoon, aes(x=x, y=y))+
  geom_point(size=1)+
  xlab("drug conc.")+
  ylab("% viability")+
  scale_y_continuous(breaks = c(0, 50, 100), limits=c(0,105), expand=c(0,0))+
  scale_x_continuous(limits=c(-5,100),expand=c(0,0))+
  geom_hline(yintercept=20, linetype="dashed", color="blue", size=0.35)+
  geom_hline(yintercept=mean(df_sen_cartoon$y), linetype="dashed", color="green", size=0.35)+
  geom_vline(xintercept=46, linetype="dashed", color="red", size=0.35)+
  theme(axis.text.y = element_text(size=size_axes_text),
        axis.title.y = element_text(size=size_axes_title, margin=margin(r=0, unit="cm")),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        #plot.margin = unit(c(-1,0, 0, 0), "cm"),
        axis.title.x = element_text(size=size_axes_title, margin=margin(t=0, unit="cm")))

fig1b_manual = plot_grid(fig1b_manual, NULL, rel_widths = c(0.8,0.2))
fig1b_manual = fig1b_manual + draw_text("IC50", x = 0.62, y = 0.85, size=size_axes_title, color="red")+
  draw_text("AUC", x = 0.7, y = 0.72, size=size_axes_title, color="green")+
  draw_text("max inh.", x = 0.72, y = 0.43, size=size_axes_title, color="blue")

  
# AUC DATA
###############################

sen = getData(list(datasource="gt", datatype="sen", tissue="skin"), remove_dups = remove_dups)
colnames(sen) = drugs

hc_CL = hclust(dist(scale(sen)), method=clust_method)
hc_drug = hclust(dist(t(scale(sen))), method=clust_method)

sen$CL = CL_pub_label(rownames(sen))
sen = sen[,c("CL", drugs)]
sen[,-1] = scale(sen[,-1])

sen_tidy = sen %>% 
  gather("Drug", "AUC", -CL)

CL_order = sen$CL[hc_CL$order]
drug_order = drugs[hc_drug$order]

sen_tidy$CL = ordered(sen_tidy$CL, levels=CL_order)
sen_tidy$Drug = ordered(sen_tidy$Drug, levels=drug_order  )

gg_sen = ggplot(sen_tidy, aes(x=Drug, y=CL)) + 
  geom_tile(aes(fill=AUC), color="white", size=size_tile_border/2)+
  theme(axis.text.y = element_blank(),
        axis.title.y = element_text(size=size_axes_title),
        axis.text.x = element_text(angle=-90, size=size_axes_text, hjust=0, vjust=0.5),
        axis.title.x = element_blank(),
        axis.ticks = element_blank(),
        axis.line = element_blank(),
        legend.position = "bottom",
        plot.margin = unit(c(0,0,1,0), "cm"))+
  ylab("Cell lines")+
  scale_fill_gradientn("Normalized AUC", 
                       na.value = 'gray35',
                       limit=c(-5,5),
                       breaks=c(-5, 0, 5),
                       #labels=c("n.s.", "0", "0.2", "0.4"),
                       colors=c("blue","white", "#FF0000"), # FF8080
                       oob = scales::squish)+
  guides(fill=guide_colorbar(title.position="top", title.theme = element_text(size=7, angle=0),
                             label.theme = element_text(size=7, angle=0), 
                             barheight=0.5, barwidth=5.5, title.hjust=0.5))


drug_types =  drugtargets_simple[match(drug_order, drugs)]
drug_type_lab = drug_type_label(drug_types)
drug_types = drug_type_lab$drug_targets
drug_target_color =  drug_type_lab$drug_target_color

df = data.frame(drug=drug_order,drug_type=drug_types)
df$drug = ordered(df$drug, levels=df$drug)

ann_drug = ggplot(df, aes(x=drug, fill=drug_type, y=1))+ 
  geom_tile(color="white", size=size_tile_border, height=1)+theme(
    legend.title = element_text(size=size_axes_text),
    legend.text = element_text(size=size_axes_text),
    axis.text = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    axis.line = element_blank(),
    plot.margin = unit(c(0.05, 0, 0.05, 0), "cm")
  )+
  scale_x_discrete(expand=c(0,0))+
  scale_fill_manual(values=drug_target_color)+
  labs(fill="Drug type")

# save for later
drug_leg = get_legend(ann_drug)

dend_drug = as.dendrogram(hc_drug)
dend_drug_data = dendro_data(dend_drug)

dg = ggplot(segment(dend_drug_data))+
  geom_segment(aes(x=x, y=y, xend=xend, yend=yend), size=0.35)+
  #coord_flip() + 
  #scale_y_reverse() +
  scale_y_continuous(expand=c(0, 0))+
  scale_x_continuous(expand=c(1/length(dend_drug_data$labels$label)/2, 0))+
  theme_dendro()+
  theme(plot.margin = unit(c(0.1, 0, -0.8, 0), "cm"))

fig1c = plot_grid(dg, ann_drug+theme(legend.position="none"), gg_sen+theme(legend.position = "none"), nrow=3, align="v", axis="y", rel_heights = c(0.05, 0.04, 0.90))
fig1c_withleg = fig1c + draw_plot(get_legend(gg_sen), x=0.5, y=0, width=0.5, heigh=0.1)


# AUC CORRELATIONS
###############################

sen = getData(list(datasource="gt", datatype="sen", tissue="skin"), remove_dups = remove_dups)
vem_dab = data.frame(Dabrafenib=sen[,"Dabrafenib", drop=F], Vemurafenib=sen[,"Vemurafenib", drop=F])

#plot_pred = function(meas, preds, ylab=T, predplot=F, legend_show=F, drug_show=T)
vemdab = plot_pred(sen[,"Dabrafenib", drop=F], sen[,"Vemurafenib", drop=F], predplot=F, drug_show=F)
vemcobi = plot_pred(sen[,"Cobimetinib", drop=F], sen[,"Vemurafenib", drop=F], predplot=F, drug_show=F)
vemdm1 = plot_pred(sen[,"DM1", drop=F], sen[,"Vemurafenib", drop=F], predplot=F, drug_show=F)

vemdab2 = vemdab+
          theme(legend.position = c(0.47,0.25), 
             legend.text=element_text(size=5))+
          scale_y_continuous(breaks=c(60, 80, 100))+
          scale_shape_manual(labels=c("BRAF V600E/K"="BRAF\nV600E/K", "NRAS"="NRAS", "Other"="Other"), values=c("BRAF V600E/K"=16,"NRAS"=17,"Other"=15))+
          scale_color_manual(labels=c("BRAF V600E/K"="BRAF\nV600E/K", "NRAS"="NRAS", "Other"="Other"), values=c("BRAF V600E/K"=colors()[29],"NRAS"=colors()[34],"Other"="green4"))

fig1d = plot_grid(vemdab2,
                  vemcobi+theme(legend.position = "none", axis.title.y=element_blank(), axis.text.y=element_blank(), axis.ticks.y = element_blank()),
                  vemdm1+theme(legend.position = "none", axis.title.y=element_blank(), axis.text.y=element_blank(), axis.ticks.y = element_blank()),
                  align="h", ncol=3, rel_widths = c(1.375,1,1))


# PREDICT AUC FROM MUTATION
###############################

datatype_x = "mutation_unspecPt"
out_gtmut = read_analysis_data(expand.grid(datasource = "gt", datatype = "mut", version="unspecPt", tissue="skin", sen="gt", method="regressiontree", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]

# out_gtmut$pvals_varsExpl_adj

gg_mut = plot_predict(out_gtmut, p_pos="ur")$gg_errorbar_varsExpl

fig1e = gg_mut + 
  guides(fill=F, color=guide_colorbar(title=expression(-log[10](P)), title.position="top", title.hjust=0, barwidth = 2.5, barheight = 0.5))+
  coord_cartesian(ylim=c(-0.43, 0.7))+
  theme(legend.position = "bottom", 
      legend.title = element_text(size=size_legend),
      legend.text = element_text(size=size_legend))

leg_pval = get_legend(fig1e)
fig1e = fig1e+theme(legend.position="none")

#inset
sen = getData(list(datasource="gt", datatype="sen", tissue="skin"), remove_dups = remove_dups)
sen = sen[,c("Vemurafenib", "Dabrafenib")]
muts = getData(list(datasource="gt", datatype="mut", version="signature"), remove_dups = remove_dups)
sen = inner_join(sen %>% mutate(CL=rownames(sen)), muts %>% mutate(CL=rownames(muts)), by="CL") %>% 
  dplyr::select(Vemurafenib, Dabrafenib, BRAF) %>% 
  gather("Drug", "AUC", -BRAF) %>% 
  mutate(Mutation = ifelse(BRAF==0, "BRAF", "Other")) %>% 
  dplyr::select(-BRAF)

inset = ggplot(sen, aes(x=Drug, y=AUC, fill=Mutation))+  
  stat_summary(fun.data = quantiles_90, geom="boxplot", position="dodge", lwd=0.4 )+
  coord_flip()+
  theme(axis.title.y=element_blank(),
        axis.ticks.y = element_blank(),
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border/2, linetype="solid"),
        axis.title = element_text(size=6),
        axis.title.x = element_text(margin=margin(t=0, unit="cm")),
        axis.text = element_text(size=6),
        legend.title = element_blank(),
        legend.margin = margin(l=-0.2,unit="cm"),
        #legend.position = "top",
        legend.text = element_text(size=6))+
  guides(fill = guide_legend(override.aes = list(size = 0.1)))


fig1e = ggdraw()+
  draw_plot(fig1e)+
  draw_plot(leg_pval, x=0.79, y=0.4)+
  draw_plot(inset, x=0.2, y=0.71, width=0.6, height=0.27)


# COMBINE
fig1ab = plot_grid(fig1a, fig1b_manual, ncol=2, rel_widths = c(0.75, 0.25), labels = c("a", "b"))
fig1ab_wspace = plot_grid(fig1ab, NULL, nrow=2, rel_heights = c(0.85, 0.15))
fig1de = plot_grid(fig1d, plot_grid(NULL, fig1e, ncol=2, rel_widths = c(0.15,0.85), labels=c("", "e"), hjust=c(0,-2.5)), nrow=2, rel_heights = c(0.3, 0.7), labels=c("d", ""), vjust=c(1, 0), hjust=c(-3.0, 0))
fig1cde = plot_grid(fig1c_withleg, fig1de, ncol=2, rel_widths = c(0.45, 0.55), labels=c("c", ""),  vjust=c(1, 0))
fig1 = plot_grid(fig1ab_wspace, fig1cde, nrow=2, rel_heights = c(0.25, 0.75))+  # 0.22 0.78
  draw_plot(drug_leg, x=0.45, y=-0.1)

save_plot(paste(FIG_PATH,"figure1_removedups", remove_dups,".pdf", sep=""), fig1, base_width = 7.4, base_height = 6.5)
save_plot(paste(FIG_SI_PATH,"figure1_removedups", remove_dups,".pdf", sep=""), fig1, base_width = 7.4, base_height = 6.5)

#################################
######## FIGURE 2 ###############
#################################


# RPPA HEATMAP
###############################

library("ggdendro")
rppa = getData(list(datasource="gt", datatype="rppa", tissue="skin"), 
                  match_CLs=list(datasource="gt", datatype="sen", tissue="skin"), 
                  remove_dups = remove_dups)
rownames(rppa)=CL_pub_label(rownames(rppa))
hc = hclust(dist(rppa), method="complete")
hc_cut = cutree(hc, 2)
hc_cut_sorted = hc_cut[hc$order]
if(mean(rppa$Akt.S473[which(hc_cut==1)])>mean(rppa$Akt.S473[which(hc_cut==2)])) {
  akt_clust_label = 1
  pten_clust_label = 2
} else {
  akt_clust_label = 2
  pten_clust_label = 1
}
dend = as.dendrogram(hc)
dend_data = dendro_data(dend)

rppa_maxvar = names(apply(rppa,2, var)[order(-apply(rppa,2, var))][1:10])


rppa_tidy = gather(data.frame(Cell.Line=rownames(rppa), rppa), "Protein", "expression", -Cell.Line) %>% 
  filter(Protein %in% rppa_maxvar)

rppa_tidy$Protein = ordered(rppa_tidy$Protein, levels=rppa_maxvar)
rppa_tidy$Cell.Line = ordered(rppa_tidy$Cell.Line, levels=rownames(rppa)[hc$order])

clust <- ifelse(hc_cut_sorted == akt_clust_label, "red", "blue")

hm = ggplot(rppa_tidy, aes(x=Protein, y=Cell.Line))+
  geom_tile(aes(fill=expression), color="white", size=size_tile_border/2)+theme(
    axis.text.x = element_text(angle=-90, size=size_axes_text, vjust=0.5, hjust=0),
    axis.text.y = element_text(size=size_axes_text, color=clust),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    axis.line = element_blank(),
    legend.position = "bottom",
    legend.title = element_text(size=size_legend),
    plot.margin = unit(c(0, 0.1, 0, 0), "cm")
  )+
  scale_x_discrete(labels=rppa_pub_label(rppa_maxvar))+
  scale_y_discrete(position="right", expand=c(0,0))+
  scale_fill_gradientn(expression(log[2](expression)), 
                       limit=c(-2,4),
                       values=rescale(c(-2, 0, 2, 4)),
                       breaks=c(-2, 0, 2, 4),
                       #labels=c("n.s.", "0", "0.2", "0.4"),
                       colors=c("blue","white", "#FF8080", "#FF0000"),
                       oob = scales::squish)+
  guides(fill=guide_colorbar(title.position="top", title.theme = element_text(size=8, angle=0),
                              label.theme = element_text(size=8, angle=0), 
                              barheight=0.65, barwidth=4.0, title.vjust = -3, title.hjust = 0, label.vjust = 15))

dg = ggplot(segment(dend_data))+
  geom_segment(aes(x=x, y=y, xend=xend, yend=yend))+
  coord_flip() + 
  scale_y_reverse() +
  scale_x_continuous(expand=c(1/length(dend_data$labels$label)/2, 0))+
  theme_dendro()+
  theme(plot.margin = unit(c(0, 0, 0, 0.2), "cm"))


fig2a = plot_grid(dg, hm, rel_widths = c(0.12, 0.88), align="h", axis="b")


# PCA
###############################

pca = prcomp(rppa)

clusterfn = function(clusters) { 
  ret = c()
  for(cluster in clusters) {
    if(cluster==akt_clust_label) {
      ret = c(ret, "AKT")
    } else
      ret = c(ret, "PTEN")
  }
  return(ret)
} 


df <- data.frame(PC1=pca$x[,1],PC2=pca$x[,2], Cluster=clusterfn(hc_cut))

gg_pca <- ggplot(df, aes(x=PC1,y=PC2,color=Cluster))+
  geom_point(size=1.0)+
  theme(legend.position = "bottom", 
        axis.title = element_text(size=size_axes_title),
        axis.text = element_text(size=size_axes_text),
        legend.text = element_text(size=size_axes_title),
        legend.title = element_text(size=size_axes_title),
        axis.title.x=element_text(margin=margin(t=0)),
        axis.title.y=element_text(margin=margin(r=-15)),
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"),
        plot.margin = unit(c(0,0,0,0), "cm"))+
  scale_color_manual(values=c("AKT"=colors()[34],"PTEN"=colors()[29]))+
  scale_x_continuous(breaks=c(-5, 0, 5))

df = data.frame(pAkt=rppa$Akt.S473, PTEN=rppa$PTEN, Cluster=clusterfn(hc_cut))

gg_akt_vs_pten <- ggplot(df, aes(x=pAkt,y=PTEN, color=Cluster))+
  geom_point(size=1.0)+
  theme(legend.position = "bottom", 
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"),
        axis.title = element_text(size=size_axes_title),
        axis.text = element_text(size=size_axes_text),
        axis.title.x=element_text(margin=margin(t=0)),
        axis.title.y = element_text(margin=margin(r=-15)),
        legend.text = element_text(size=size_axes_title),
        legend.title = element_text(size=size_axes_title),
        plot.margin = unit(c(0,0,0,0), "cm"))+
  scale_color_manual(values=c("AKT"=colors()[34],"PTEN"=colors()[29]))+
  xlab(expression(Akt^{S473}))

fig2bc_leg = get_legend(gg_pca)

fig2b = gg_pca+theme(legend.position = "none")
fig2c = gg_akt_vs_pten+theme(legend.position = "none")

pc1 = abs(pca$rotation[,1][order(-abs(pca$rotation[,1]))][1:20])
df = data.frame(prot=names(pc1), PC1=pc1)
df$prot = ordered(df$prot, levels=names(pc1))

fig2d = ggplot(df, aes(x=prot, y=PC1))+
  geom_bar(stat="identity")+theme(
    panel.background = element_rect(colour = "black", fill=NA, size=1, linetype="solid"),
    axis.title.x = element_blank(),
    axis.title.y = element_text(size=size_axes_title),
    axis.text = element_text(size=size_axes_text),
    axis.text.x = element_text(angle=-90, hjust=0, vjust=0.5),
    plot.margin = unit(c(0.7,0,0,0), "cm"))+
  scale_x_discrete(labels=rppa_pub_label(df$prot))+
  ylab("PC1")+
  scale_y_continuous(limits=c(0,1.02*max(df$PC1)), expand=c(0,0), breaks=c(0,0.25, 0.50))


# DRUG SENSIVIVITY AKT/PTEN CLUSTERS
####################################

sen = getData(list(datasource="gt", datatype="sen", tissue="skin"), 
              match_CLs = list(datasource="gt", datatype="rppa", tissue="skin"),
              remove_dups = remove_dups)
rownames(sen)=CL_pub_label(rownames(sen))
df_tidy = gather(data.frame(Cell.Line=rownames(rppa), sen, Cluster=hc_cut, check.names = F), "Drug", "AUC", -Cell.Line, -Cluster)
df_tidy = df_tidy[,c("Cell.Line", "Drug", "AUC", "Cluster")]

gdc0068 = read.csv(file="../SourceData/GDC0068.csv",head=TRUE,sep=",")
gdc0068$Cell.Line = rename_canonical(gdc0068$Cell.Line)
if(remove_dups) {
  gdc0068 = remove_duplicates(gdc0068)
}
colnames(gdc0068) = c("Cell.Line", "AUC")
gdc0068$Cell.Line = CL_pub_label(gdc0068$Cell.Line)
gdc0068 = inner_join(gdc0068, data.frame(Cell.Line=names(hc_cut), Cluster=hc_cut))
gdc0068$Drug=rep("GDC0068", length(gdc0068$AUC))
gdc0068 = gdc0068[,c("Cell.Line", "Drug", "AUC", "Cluster")]

df_tidy = rbind(df_tidy, gdc0068)

df_tidy$Cluster = clusterfn(df_tidy$Cluster)
df_tidy$DrugTarget = unlist(sapply(df_tidy$Drug, function(x) drugtargets_simple_gdc0068[which(x==drugs_gdc0068)]))
drug_target_color = drug_type_label(as.character(df_tidy$DrugTarget))$drug_target_color
df_tidy$DrugTarget = drug_type_label(as.character(df_tidy$DrugTarget))$drug_targets
df_tidy$Drug = ordered(df_tidy$Drug, levels=drugs_gdc0068[order(drugtargets_simple_gdc0068)])


pvals = c()
for(drug in unique(df_tidy$Drug)) {
  pvals = c(pvals, t.test(df_tidy[df_tidy$Drug==drug & df_tidy$Cluster=="AKT","AUC"], 
                          df_tidy[df_tidy$Drug==drug & df_tidy$Cluster=="PTEN","AUC"], na.action=na.omit)$p.value)
}
names(pvals) = unique(df_tidy$Drug)
pvals_adj = p.adjust(pvals, method="BH")

pvals_adj_gdc0068 = pvals_adj['GDC0068']
if(pvals_adj_gdc0068<0.05 & pvals_adj_gdc0068>0.01) {
  label_sig = '*'
} else if(pvals_adj_gdc0068<0.01 & pvals_adj_gdc0068>0.001) {
  label_sig = '**'
} else if(pvals_adj_gdc0068<0.001) {
  label_sig = '***'
} else {
  label = ''
}

fig2e = ggplot(df_tidy, aes(x=Drug, y=AUC, color=Cluster))+
  stat_summary(fun.data = quantiles_90, geom="boxplot", position="dodge", lwd=0.4 )+
  annotate("segment", x=0.6, xend=1.8, y=112, yend=112)+
  annotate("text", x=1.2, y=113, label=label_sig, size=2.2)+
  geom_tile(aes(fill=DrugTarget, y=2, height=3), color="white", size=size_tile_border)+
  theme(axis.text.x = element_text(size=size_axes_text, angle=-90,  hjust=0, vjust=0.5),
        axis.title.y = element_text(size=size_axes_title),
        axis.text.y = element_text(size=size_axes_text),
        legend.title = element_text(size=size_legend),
        panel.background = element_rect(colour = "black", fill=NA, size=1, linetype="solid"),
        legend.text = element_text(size=size_legend), # FIXME, MAKE LEGEND LOOK NICE
        legend.text.align = 0,
        axis.title.x = element_blank())+
  coord_cartesian(ylim=c(5,115))+
  scale_fill_manual(values=drug_target_color)

gg_legend_drugtype = get_legend(fig2e+guides(color=F, fill=guide_legend("Drug type",  keywidth=0.5, keyheight=0.5 )))

fig2e = fig2e+guides(fill=F, color=guide_legend(""))+theme(legend.position=c(0.25, 0.19))

plots = align_plots(fig2b, fig2c, fig2d, fig2e, align="v")
fig2bcde = plot_grid(plot_grid(plots[[1]], plots[[2]],  align="h", labels = c("b","d"), vjust = c(1,1)), plots[[3]], plots[[4]], labels=c("","c", "e"), nrow=3, rel_heights = c(0.17,0.32,0.46))

fig2bcde = fig2bcde + draw_plot(fig2bc_leg, x=0.41, y=0.77, width=0.3, height=0.05)

plots2 = align_plots(fig2a, plots[[1]], align="h", axis="t")

fig2 = plot_grid(plots2[[1]], fig2bcde, ncol=2, labels=c("a",""), align="h", axis="t", vjust=c(1, 0), rel_widths = c(0.4, 0.6))
fig2 = fig2 + draw_plot(gg_legend_drugtype, x=0.27, y=0.13, width=0.2, height=0.05)
save_plot(paste(FIG_PATH,"figure2_removedups", remove_dups,".pdf", sep=""), fig2, base_height = 6.1, base_width = 5)
save_plot(paste(FIG_SI_PATH,"figure2_removedups", remove_dups,".pdf", sep=""), fig2, base_height = 6.1, base_width = 5)


#################################
######## FIGURE 3 ###############
#################################

# CARTOON
#######################################

library(magick)
fig3a = ggdraw()+
  draw_image(magick::image_read_pdf(paste(FIG_PATH,"3_pls_cv.pdf", sep=""), density = 600))


# SELECTED DRUG SENSIVIVITY PREDICTIONS
#######################################

out = predict_wrapper(dataX=list(datasource="gt", datatype="rppa", tissue="skin"), dataY=list(datasource="gt", datatype="sen", tissue="skin"), method=method, Nrep=100, Nbg=0, Ncore=5, remove_dups=remove_dups, return_preds=T)

cors_sorted_idx = order(-out$cors)

pred1 = plot_pred(out$data_y[,cors_sorted_idx[1],drop=F], out$preds[,cors_sorted_idx[1],drop=F])
pred2 = plot_pred(out$data_y[,cors_sorted_idx[2],drop=F], out$preds[,cors_sorted_idx[2],drop=F])
predvem = plot_pred(out$data_y[,"Vemurafenib",drop=F], out$preds[,"Vemurafenib",drop=F])
predfail = plot_pred(out$data_y[,"Gemcitabine",drop=F], out$preds[,"Gemcitabine",drop=F])+
  scale_shape_manual(labels=c("BRAF V600E/K"="BRAF", "NRAS"="NRAS", "Other"="Other"), values=c("BRAF V600E/K"=16,"NRAS"=17,"Other"=15))+
  scale_color_manual(labels=c("BRAF V600E/K"="BRAF", "NRAS"="NRAS", "Other"="Other"), values=c("BRAF V600E/K"=colors()[29],"NRAS"=colors()[34],"Other"="green4"))


fig3b = plot_grid(pred1+theme(legend.position = "none"),
          pred2+theme(legend.position = "none"),
          predvem+theme(legend.position = "none"),
          predfail+theme(legend.position = c(0.55,0.83), legend.title = element_blank()),
          labels=c("b", "", "", ""),
          ncol =2, align="hv")

fig3b_col = plot_grid(pred1+theme(legend.position = "none", axis.title.x = element_blank()),
                      pred2+theme(legend.position = "none", axis.title.x = element_blank()),
                      predvem+theme(legend.position = "none", axis.title.x = element_blank()),
                      predfail+theme(legend.position = c(0.55,0.83), legend.title = element_blank()),
                      labels=c("b", "", "", ""),
                      ncol =1, align="v")


# RPPA PREDICTION
#######################################

out_gt_rppa = read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="pls", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
gg_rppa = plot_predict(out_gt_rppa)$gg_errorbar_cors

legend_pval = get_legend(gg_rppa+
  theme(legend.position = "bottom")+
  guides(fill=F, color=guide_colorbar(title.position="top", title.theme = element_text(size=8, angle=0),
                                      label.theme = element_text(size=8, angle=0), 
                                      barheight=0.40, barwidth=2.5, title.vjust = 1, title.hjust = 0)))

fig3c = gg_rppa + guides(color=F, fill=guide_legend(title.theme = element_text(size=size_legend, angle=0),
                            label.theme = element_text(size=size_legend, angle=0),
                            keyheight=0.65, keywidth=0.65))+
      theme(legend.text = element_text(size=size_legend),
            panel.border = element_rect(linetype = "solid", color="black", fill = NA, size=1.0))
fig3c = ggdraw(fig3c)+
  draw_plot(legend_pval, x=0.63, y=0.38)


# PLS COEFFICIENT HEATMAP
#######################################

out = predict_wrapper(dataX=list(datasource="gt", datatype="rppa", tissue="skin"), dataY=list(datasource="gt", datatype="sen", tissue="skin"), method="pls", remove_dups = remove_dups, Nrep=1, Nbg=0, return_model = T)

predictive_drugs = names(which(out_gt_rppa$cors>0.25)) # get predictive drugs from FULL run
# Find drugs that are predictive and that have non-zero coefficients
rppa = names(out$models$Cobimetinib$coefficients[,,1])
coefs = matrix(NA, ncol = length(predictive_drugs), nrow=length(rppa))
rownames(coefs) = rppa
colnames(coefs) = predictive_drugs

for(drug in predictive_drugs) {
  drug_ncomp = paste(drug,"_ncomp",sep="")
  ncomp = out$models[[paste(drug,"_ncomp",sep="")]]
  coefs[,drug] = out$models[[drug]]$coefficients[,,ncomp]
}

write.csv(coefs, file="gt_mel_rppa_coefs.csv")

coefs_scaled = scale(coefs)

coefs_tidy = data.frame(coefs_scaled, RPPA=rppa) %>% 
  gather("Drug", "val",-RPPA)

hc_drug = hclust(dist(t(coefs_scaled)), method="complete")
hc_rppa = hclust(dist(coefs_scaled), method="complete")

rppa_order = rppa[hc_rppa$order]
drug_order = rev(predictive_drugs[hc_drug$order])

coefs_tidy$RPPA = ordered(coefs_tidy$RPPA, levels=rppa_order)
coefs_tidy$Drug = ordered(coefs_tidy$Drug, levels=drug_order)

hm = ggplot(coefs_tidy, aes(x=Drug, y=RPPA))+
  geom_tile(aes(fill=val), color="gray", size=size_tile_border)+theme(
    axis.text.x = element_text(angle=-90, size=size_axes_text, vjust=0.5, hjust=0),
    axis.text.y = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    axis.line = element_blank(),
    plot.margin = unit(c(-0.1, 0.1, 0, 0), "cm"),
    legend.title = element_text(size=size_legend)
  )+
  scale_x_discrete(expand=c(0,0))+
  scale_fill_gradientn("PLS coefficient", 
                       limit=c(-3, 3),
                       breaks=c(-3, 0, 3),
                       labels=c("sensitive", "", "resistant"),
                       colors=c("blue","white", "#FF0000"), # FF8080", 
                       oob = scales::squish)+
  guides(fill=guide_colorbar(title.position="left", title.theme = element_text(size=8, angle=90),
                             label.theme = element_text(size=7, angle=90, hjust=0.3), 
                             barheight=3.5, barwidth=0.45))

drug_types =  drugtargets_simple[match(drug_order, drugs)]
drug_type_lab = drug_type_label(drug_types)
drug_types = drug_type_lab$drug_targets
drug_target_color =  drug_type_lab$drug_target_color
df = data.frame(drug=drug_order,drug_type=drug_types)
df$drug = ordered(df$drug, levels=df$drug)

ann_drug = ggplot(df, aes(x=drug, fill=drug_type, y=1))+ 
  geom_tile(color="white", size=size_tile_border, height=1)+theme(
    axis.text = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    axis.line = element_blank(),
    plot.margin = unit(c(0.05, 0, 0.05, 0), "cm")
  )+
  scale_x_discrete(expand=c(0,0))+
  scale_fill_manual(values=drug_target_color)+
  labs(fill="Drug type")

ann_drug_leg = get_legend(ann_drug)
ann_drug = ann_drug+theme(legend.position = "none")

dend_drug = rev(as.dendrogram(hc_drug))
dend_drug_data = dendro_data(dend_drug)

dg = ggplot(segment(dend_drug_data))+
  geom_segment(aes(x=x, y=y, xend=xend, yend=yend), size=0.35)+
  #coord_flip() + 
  #scale_y_reverse() +
  scale_y_continuous(expand=c(0, 0))+
  scale_x_continuous(expand=c(1/length(dend_drug_data$labels$label)/2, 0))+
  theme_dendro()+
  theme(plot.margin = unit(c(0.1, 0, -0.8, 0), "cm"))

hmd = plot_grid(dg, ann_drug, hm+theme(legend.position = "none"), nrow=3, align="v", axis="y", rel_heights = c(0.05,0.04, 0.7))
fig3d = plot_grid(hmd, get_legend(hm), ncol=2, rel_widths = c(0.8, 0.2))


hmd_si = plot_grid(dg, ann_drug, hm+theme(legend.position = "none", axis.text.y=element_text(size=4, hjust=1)), nrow=3, align="v", axis="y", rel_heights = c(0.05,0.04, 0.7))
fig3d_si = plot_grid(hmd_si, plot_grid(ann_drug_leg, get_legend(hm), nrow=2, rel_heights = c(0.4, 0.6)), ncol=2, rel_widths = c(0.8, 0.2))
save_plot(filename=paste(FIG_SI_PATH,"pls_rppa_coefs_removeDups", remove_dups,".pdf", sep=""), fig3d_si, base_height = 5, base_width = 5)

# PLS coefs zoom-in
if(!remove_dups) {
  coefs_scaled_rafVSmek = coefs_scaled[,c("Vemurafenib", "Dabrafenib", "GDC0994", "Cobimetinib")]
  absdiff = abs((coefs_scaled_rafVSmek[,"Vemurafenib"]+coefs_scaled_rafVSmek[,"Dabrafenib"])/2-(coefs_scaled_rafVSmek[,"GDC0994"]+coefs_scaled_rafVSmek[,"Cobimetinib"])/2)
  absdiff = absdiff[order(absdiff, decreasing = T)]
  abstot = abs((coefs_scaled_rafVSmek[,"Vemurafenib"]+coefs_scaled_rafVSmek[,"Dabrafenib"])/2+(coefs_scaled_rafVSmek[,"GDC0994"]+coefs_scaled_rafVSmek[,"Cobimetinib"])/2)
  abstot = abstot[order(abstot, decreasing = T)]
  coefs_scaled_rafVSmek_zoom = coefs_scaled_rafVSmek[union(names(absdiff)[1:12], names(abstot)[1:17]) ,]
  gg_rafVSmek = plot_drugX_heatmap(coefs_scaled_rafVSmek_zoom, list(drugs=c("Vemurafenib", "Dabrafenib", "GDC0994", "Cobimetinib"), drug_targets=rep("MAPK", 4)), gradient = 'PLScoefs', axis.text.y=TRUE, draw_colorbar_legend = F, draw_annotation_legend=F, parse_ylab = T)
  save_plot(filename=paste(FIG_SI_PATH,"pls_rppa_coefs_rafVSmek_removeDups", remove_dups,".pdf", sep=""), gg_rafVSmek, base_height = 4, base_width = 5)
} else {
  coefs_scaled_rafVSmek = coefs_scaled[,c("Vemurafenib", "Dabrafenib", "Cobimetinib")]
  absdiff = abs((coefs_scaled_rafVSmek[,"Vemurafenib"]+coefs_scaled_rafVSmek[,"Dabrafenib"])/2-coefs_scaled_rafVSmek[,"Cobimetinib"])
  absdiff = absdiff[order(absdiff, decreasing = T)]
  abstot = abs((coefs_scaled_rafVSmek[,"Vemurafenib"]+coefs_scaled_rafVSmek[,"Dabrafenib"])/2+coefs_scaled_rafVSmek[,"Cobimetinib"])
  abstot = abstot[order(abstot, decreasing = T)]
  coefs_scaled_rafVSmek_zoom = coefs_scaled_rafVSmek[union(names(absdiff)[1:12], names(abstot)[1:17]) ,]
  gg_rafVSmek = plot_drugX_heatmap(coefs_scaled_rafVSmek_zoom, list(drugs=c("Vemurafenib", "Dabrafenib", "Cobimetinib"), drug_targets=rep("MAPK", 3)), gradient = 'PLScoefs', axis.text.y=TRUE, draw_colorbar_legend = F, draw_annotation_legend=F, parse_ylab = T)
  save_plot(filename=paste(FIG_SI_PATH,"pls_rppa_coefs_rafVSmek_removeDups", remove_dups,".pdf", sep=""), gg_rafVSmek, base_height = 4, base_width = 5)
}  

coefs_scaled_chemo = coefs_scaled[,c("Paclitaxel", "DM1", "MMAE", "Docetaxel")]
abstot = abs((coefs_scaled_chemo[,"Paclitaxel"]+coefs_scaled_chemo[,"DM1"])/2+(coefs_scaled_chemo[,"MMAE"]+coefs_scaled_chemo[,"Docetaxel"])/2)
abstot = abstot[order(abstot, decreasing = T)]
coefs_scaled_chemo_zoom = coefs_scaled_chemo[names(abstot)[1:12] ,]
gg_chemo = plot_drugX_heatmap(coefs_scaled_chemo_zoom, list(drugs=c("Paclitaxel", "DM1", "MMAE", "Docetaxel"), drug_targets=rep("Chemo", 4)), gradient = 'PLScoefs', axis.text.y=TRUE, draw_colorbar_legend = F, draw_annotation_legend=F, parse_ylab = T)
#save_plot(filename=paste(FIG_SI_PATH,"pls_rppa_coefs_chemo_removeDups", remove_dups,".pdf", sep=""), gg_chemo, base_height = 4, base_width = 5)

coefs_scaled_hdac = coefs_scaled[,c("TrichostatinA", "BRD6929")]
abstot = abs((coefs_scaled_hdac[,"TrichostatinA"]+coefs_scaled_hdac[,"BRD6929"])/2)
abstot = abstot[order(abstot, decreasing = T)]
coefs_scaled_hdac_zoom = coefs_scaled_hdac[names(abstot)[1:12] ,]
gg_hdac = plot_drugX_heatmap(coefs_scaled_hdac_zoom, list(drugs=c("TrichostatinA", "BRD6929"), drug_targets=rep("HDAC", 2)), gradient = 'PLScoefs', axis.text.y=TRUE, draw_colorbar_legend = F, draw_annotation_legend=F, parse_ylab = T)
#save_plot(filename=paste(FIG_SI_PATH,"pls_rppa_coefs_hdac_removeDups", remove_dups,".pdf", sep=""), gg_hdac, base_height = 4, base_width = 5)


# COMBINE
#######################################

col1 = plot_grid(fig3a, fig3b_col, ncol=1, rel_heights = c(0.3, 0.7), labels=c("a", "b"))
fig3defg = plot_grid(
              plot_grid(fig3d+theme(plot.margin = unit(c(0,0,0,0.5), "cm")), 
                        gg_rafVSmek, 
                      labels=c("d", "e"), ncol=2),
              NULL,
              plot_grid(gg_chemo+theme(plot.margin = unit(c(0,0,0,0.5), "cm")), 
                        gg_hdac+theme(plot.margin = unit(c(0,0,0,0.5), "cm")), 
                      labels=c("f", "g"), ncol=2), 
            ncol=1, rel_heights = c(0.61, 0.015, 0.41))
col2 = plot_grid(NULL, fig3c, fig3defg, ncol=1, rel_heights = c(0.05, 0.31, 0.69), labels=c("c", ""))
fig3 = plot_grid(col1, NULL, col2, ncol=3, rel_widths = c(0.3, 0.05, 0.7))

save_plot(paste(FIG_PATH, "figure3_removedups", remove_dups,".pdf", sep=""), fig3, base_width = 6.7, base_height = 8.6)
save_plot(paste(FIG_SI_PATH,"figure3_removedups", remove_dups,".pdf", sep=""), fig3, base_width = 6.7, base_height = 8.6)



#################################
######## FIGURE 4 ###############
#################################

out_gt_rnaseq = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="pls", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]

gg_rnaseq = plot_predict(out_gt_rnaseq)$gg_errorbar_cors
gg_rnaseq = gg_rnaseq + theme(legend.position = "bottom")+
  guides(color=guide_colorbar(title.position="top", title.theme = element_text(size=8, angle=0),
                              label.theme = element_text(size=8, angle=0), 
                              barheight=0.40, barwidth=2.7, title.vjust = 1, title.hjust = 0))+
  guides(fill=guide_legend(title.theme = element_text(size=size_legend, angle=0),
                           label.theme = element_text(size=size_legend, angle=0),
                           keyheight=0.65, keywidth=0.65))
legend_drugtype = get_legend(gg_rnaseq+guides(color=F))
legend_pval = get_legend(gg_rnaseq+guides(fill=F))
gg_rnaseq = gg_rnaseq+guides(color=F, fill=F)
gg_rnaseq = gg_rnaseq +  theme(panel.border = element_rect(linetype = "solid", color="black", fill = NA, size=1.0))
fig4a = ggdraw(gg_rnaseq)+
  draw_plot(legend_pval, x=0.77, y=0.38)+
  draw_plot(legend_drugtype, x=0.3, y=0.05, width=0.4, height=0)


# RPPA VS RNASEQ VS RPPA+RNASEQ
###############################

out_gt_rpparnaseq_early = read_analysis_data(expand.grid(datasource = "gt", datatype = "rpparnaseq", version="-", tissue="skin", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rpparnaseq_late = read_analysis_data(expand.grid(datasource = "gt", datatype = "rpparnaseq", version="-", tissue="skin", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="late" ), return_outs = T)[[1]]

fig4b_hm = plot_corsheatmap(outlist=list(out_gt_rppa, out_gt_rnaseq, out_gt_rpparnaseq_late), 
                         labels=c("Protein","mRNA","Protein+mRNA"), plot_legend = F, colorbar_height = 2.3)
fig4b = fig4b_hm$fig
gg_hm_legend_ann = fig4b_hm$leg_ann
gg_hm_legend_colorbar = fig4b_hm$leg_colorbar


# PRE-TREATMENT VS POST-TREATMENT
#################################

# Removed - unstable


# ENDOMETRIUM PREDICTIONS
#################################

out_endo_rppa = read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="endometrium", sen="gt", method="pls", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_endo_rnaseq = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="endometrium", sen="gt", method="pls", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_endo_rpparnaseq_late = read_analysis_data(expand.grid(datasource = "gt", datatype = "rpparnaseq", version="-", tissue="endometrium", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="late" ), return_outs = T)[[1]]

gg_endo_rppa = plot_predict(out_endo_rppa)$gg_errorbar_cors
gg_endo_rnaseq = plot_predict(out_endo_rnaseq)$gg_errorbar_cors


fig_endo_hm = plot_corsheatmap(outlist=list(out_endo_rppa, out_endo_rnaseq, out_endo_rpparnaseq_late), 
                         labels=c("Protein","mRNA","Protein+mRNA"))$fig


# ENDOMETRIUM-MELANOMA CROSS-PREDICTION
#######################################

out_melanoma = predict_wrapper(dataX=list(datasource="gt", datatype="rppa", tissue="skin", version="endosel"), dataY=list(datasource="gt", datatype="sen", tissue="skin"), method=method, remove_dups = remove_dups, Nrep=1, Nbg=0, Ncore=1, return_model = T)
xvar_mel_endosel = colnames(getData(list(datasource="gt", datatype="rppa", tissue="skin", version="endosel")))
rppa_endo = getData(list(datasource="gt", datatype="rppa", tissue="endometrium"), match_CLs=list(datasource="gt", datatype="sen", tissue="endometrium"), remove_dups = remove_dups)
sen_endo = getData(list(datasource="gt", datatype="sen", tissue="endometrium"), match_CLs=list(datasource="gt", datatype="rppa", tissue="endometrium"), remove_dups = remove_dups)
colnames(rppa_endo) = gsub("[._ -]","",tolower(colnames(rppa_endo)))
m = match(gsub("[._ -]","",tolower(xvar_mel_endosel)), colnames(rppa_endo))
rppa_endo = rppa_endo[,m]
colnames(rppa_endo) = xvar_mel_endosel

meldrugs = names(out_melanoma$models)[!grepl("ncomp",names(out_melanoma$models))]
endodrugs = colnames(sen_endo)
melendodrugs = intersect(meldrugs,endodrugs)
sen_endo = sen_endo[,melendodrugs]
cors = c()
for(drugi in 1:length(melendodrugs)) {
    drug = melendodrugs[drugi]
    comps = out_melanoma$models[[paste(drug,"_ncomp",sep="")]]
    preds = predict(out_melanoma$models[[drug]], newdata=as.matrix(rppa_endo), comps=comps)
    cors[drugi] = cor(preds, sen_endo[,drug], use="complete.obs", method="spearman" )
}
names(cors) = melendodrugs

cors_bg = matrix(NA, ncol = length(melendodrugs), nrow = Nrep )
colnames(cors_bg) = melendodrugs
for(r in 1:Nrep) {
  cors_tmp = c()
  for(drugi in 1:length(melendodrugs)) {
    drug = melendodrugs[drugi]
    comps = out_melanoma$models[[paste(drug,"_ncomp",sep="")]]
    preds = predict(out_melanoma$models[[drug]], newdata=as.matrix(rppa_endo), comps=comps)
    cors_tmp[drugi] = cor(preds, sen_endo[sample(nrow(sen_endo)),drug], use="complete.obs", method = "spearman" )
  }
  cors_bg[r,] = cors_tmp
}

out=list()
out$cors = cors
out$cors_rep = as.matrix(rbind(cors,cors))
out$cors_bg = cors_bg
out$varsExpl = cors*cors # nonsense, not used, fill 'out' with required fields
out$varsExpl_rep = out$cors_rep*out$cors_rep # nonsense
out$varsExpl_bg = cors_bg*cors_bg # nonsense
out$argstr = "Melanoma-Edometrium cross-test"
dt = getDrugTarget(list(datasource="gt", datatype="sen", tissue="endometrium"), match_CLs=list(datasource="gt", datatype="rppa", tissue="endometrium"), remove_dups=remove_dups)
m = match(names(out$cors), dt$drugs)
m = m[!is.na(m)]
out$drug_targets = dt$drug_targets[m]

pvals_cors = c()
for(d in seq(1,length(melendodrugs))) {
  pval_cor = min(1, (length(which(cors_bg[,d]>cors[d]))+1)/length(cors_bg[,d]) )
  pvals_cors = c(pvals_cors,pval_cor)
}
names(pvals_cors) = melendodrugs
pvals_cors_adj = p.adjust(pvals_cors,method="BH")

out$pvals_cors = pvals_cors
out$pvals_cors_adj = pvals_cors_adj
out$pvals_varsExpl = pvals_cors # 
out$pvals_varsExpl_adj = pvals_cors_adj

gg_melendo_cross = plot_predict(out, p_pos="ur")$gg_errorbar_cors


# COMBINE
#################################

gg_melendo_cross_noguide = gg_melendo_cross+guides(fill=F, color=F)+
  scale_y_continuous(breaks=c(-0.25,0.0, 0.25, 0.5))

row1 = plot_grid(fig4a, fig4b, ncol = 2, rel_widths = c(0.65, 0.35), labels = c("a", "b"), hjust=c(0,0))
row1 = row1 + draw_plot(gg_hm_legend_colorbar, x=0.90, y=-0.4) # x=0.92, y=0.10, width=0.1, height=0.04
row2 = plot_grid(gg_melendo_cross_noguide, fig_endo_hm, ncol = 2, rel_widths = c(0.65, 0.35), labels = c("c", "d"), hjust=c(0,0))
fig4 = plot_grid(row1, row2, ncol=1)

save_plot(paste(FIG_PATH, "figure4_removedups", remove_dups,".pdf", sep=""), fig4, base_height = 5.5, base_width = 5.5)
save_plot(paste(FIG_SI_PATH,"figure4_removedups", remove_dups,".pdf", sep=""), fig4, base_height = 5.5, base_width = 5.5)


#################################
######## FIGURE 5 ###############
#################################

df_vol = read_analysis_data(rbind(expand.grid(datasource = "ccle", datatype = DATATYPE_NOMUT, version="-", tissue=TISSUE_CCLE_ALL, sen=SEN_CCLE, method="pls", matched="TRUE", remove_dups=F, integration="early" ),
                                  expand.grid(datasource = "ccle", datatype = "mut", version="-", tissue=TISSUE_CCLE_ALL, sen=SEN_CCLE, method="regressiontree", matched="TRUE", remove_dups=F, integration="early" )), return_outs = F)

df_vol$tissue = firstup(tissue2print(df_vol$tissue))
df_vol$datatype = datatype2print(df_vol$datatype)
df_vol$datatype = ordered(df_vol$datatype, levels=c("mRNA", "Protein", "Mutation"))
df_vol$sen = sen2print(df_vol$sen)

# df_vol %>% filter(datatype=="Mutation", tissue=="Pan-cancer", matched==TRUE, remove_dups==FALSE) %>% dplyr::select(-version, -pval_cor, -pval_varExpl, -integration) %>%  arrange(-cor)

tissues_mmp_complete = function(df) {
    df %>% 
    dplyr::select(tissue, datatype) %>% 
    distinct %>% 
    arrange(tissue) %>% 
    group_by(tissue) %>% 
    summarise(n=n()) %>% 
    filter(n==3) %>% 
    dplyr::select(tissue) %>% 
    as_data_frame
}

tissues_complete = tissues_mmp_complete(df_vol)

df_vol_complete = df_vol %>% 
  filter(tissue %in% as.character(data.frame(tissues_complete)[,1]))


# VOLCANO PLOT
#################################


gg_vol_cor = ggplot(df_vol, aes(x=cor, y=-log10(pval_cor), color=tissue))+
  geom_point(size=0.5)+
  ylab(expression(-log[10](P)))+
  xlab("Spearman rank correlation")+
  labs(color="Tissue")+
  theme(axis.text = element_text(size=size_axes_text),
        axis.title = element_text(size=size_axes_title),
        legend.text = element_text(size=size_legend),
        legend.title = element_text(size=size_legend),
        strip.text = element_text(size=size_axes_title))+
  labs(color="")+
  facet_grid( datatype ~ sen)


# RPPA VS RNASEQ VS RPPA+RNASEQ within tissue
######################################################

# if one drug is measured in both sens, average
df_tidy = df_vol_complete %>% 
  #dplyr::select(-varExpl) %>% 
  group_by(datatype, tissue, drug, drug_target) %>% 
  summarise(cor = mean(cor, na.rm=T), varExpl = mean(varExpl, na.rm=T),  
            pval_cor = mean(pval_cor, na.rm=T), pval_varExpl = mean(pval_varExpl, na.rm=T)  ) %>% 
  group_by(tissue, drug) %>%  # drugs sensitivity must exist for
  mutate(n=n()) %>%           # genomic+transcriptomic+proteomic data
  filter(n==3) %>% 
  dplyr::select(-n) %>% 
  ungroup

df_tidy_tissueDrugList = unique(paste(df_tidy$tissue,df_tidy$drug,sep="==="))

df_wide = df_tidy %>% 
  gather(variable, value, -(datatype:drug_target)) %>% 
  unite(temp, datatype, variable) %>% 
  spread(temp, value)


gg_mutVsRppaVsRnaseq = ggplot(df_tidy, aes(x=tissue, y=cor, fill=datatype))+
  geom_boxplot(outlier.size=0, outlier.stroke = 0, coef=0, fatten=1)+
  geom_point(size=0.5, alpha=0.3, position = position_jitterdodge(jitter.width = 0.05))+
  ylab("Spearman rank correlation")+
  theme(axis.text.x = element_text(colour = "black",size=size_axes_text,angle=-90,hjust=0,vjust=0.5),
        axis.text.y = element_text(colour = "black",size=size_axes_text),
        axis.title = element_text(size=size_axes_title),
        legend.key = element_blank(),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"))+
  labs(fill="")+
  scale_fill_manual(values = c('mRNA'=CB_PALETTE[1], 'Protein'=CB_PALETTE[2], 'Mutation'=CB_PALETTE[3] ))+
  xlab("")

gg_mutVsRppaVsRnaseq_varExpl = ggplot(df_tidy, aes(x=tissue, y=varExpl, fill=datatype))+
  geom_boxplot(outlier.size=0, outlier.stroke = 0, coef=0, fatten=1)+
  geom_point(size=0.5, alpha=0.3, position = position_jitterdodge(jitter.width = 0.05))+
  ylab("Variance explained")+
  theme(axis.text.x = element_text(colour = "black",size=size_axes_text,angle=-90,hjust=0,vjust=0.5),
        axis.text.y = element_text(colour = "black",size=size_axes_text),
        axis.title = element_text(size=size_axes_title),
        legend.key = element_blank(),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"))+
  labs(fill="")+
  scale_fill_manual(values = c('mRNA'=CB_PALETTE[1], 'Protein'=CB_PALETTE[2], 'Mutation'=CB_PALETTE[3] ))+
  xlab("")

save_plot(filename=paste(FIG_SI_PATH,"gg_mutVsRppaVsRnaseq_varExpl.pdf", sep=""), gg_mutVsRppaVsRnaseq_varExpl, base_height = 4, base_width = 5.2)


gg_mutVsRppaVsRnaseq_pvalcor = ggplot(df_tidy, aes(x=tissue, y=-log10(pval_cor), fill=datatype))+
  geom_boxplot(outlier.size=0, outlier.stroke = 0, coef=0, fatten=1)+
  geom_point(size=0.5, alpha=0.3, position = position_jitterdodge(jitter.width = 0.05))+
  ylab("-log10(pval)")+
  theme(axis.text.x = element_text(colour = "black",size=size_axes_text,angle=-90,hjust=0,vjust=0.5),
        axis.text.y = element_text(colour = "black",size=size_axes_text),
        axis.title = element_text(size=size_axes_title),
        legend.key = element_blank(),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"))+
  labs(fill="")+
  scale_fill_manual(values = c('mRNA'=CB_PALETTE[1], 'Protein'=CB_PALETTE[2], 'Mutation'=CB_PALETTE[3] ))+
  xlab("")

save_plot(filename=paste(FIG_SI_PATH,"gg_mutVsRppaVsRnaseq_pvalcor.pdf", sep=""), gg_mutVsRppaVsRnaseq_pvalcor, base_height = 4, base_width = 5.2)

gg_mutVsRppaVsRnaseq_pvalvarExpl = ggplot(df_tidy, aes(x=tissue, y=-log10(pval_varExpl), fill=datatype))+
  geom_boxplot(outlier.size=0, outlier.stroke = 0, coef=0, fatten=1)+
  geom_point(size=0.5, alpha=0.3, position = position_jitterdodge(jitter.width = 0.05))+
  ylab("-log10(pval)")+
  theme(axis.text.x = element_text(colour = "black",size=size_axes_text,angle=-90,hjust=0,vjust=0.5),
        axis.text.y = element_text(colour = "black",size=size_axes_text),
        axis.title = element_text(size=size_axes_title),
        legend.key = element_blank(),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"))+
  labs(fill="")+
  scale_fill_manual(values = c('mRNA'=CB_PALETTE[1], 'Protein'=CB_PALETTE[2], 'Mutation'=CB_PALETTE[3] ))+
  xlab("")

save_plot(filename=paste(FIG_SI_PATH,"gg_mutVsRppaVsRnaseq_pvalvarExpl.pdf", sep=""), gg_mutVsRppaVsRnaseq_pvalvarExpl, base_height = 4, base_width = 5.2)


# CROSS TISSUE TYPE PREDICTIONS
#################################

cross_analysis = function(df_unfair, df_fair) {
  
  df_fair = df_fair %>% 
    dplyr::select(datatype, tissue, sen,drug, cor_cross) %>% 
    gather(key="cor_type", value="cor", cor_cross) %>% 
    mutate(cor_type="cor_cross_fair")
  
  df_unfair = df_unfair %>%
    dplyr::select(datatype, tissue, sen,drug, cor_cross, cor_within) %>% 
    gather(key="cor_type", value="cor", (cor_cross:cor_within))
  
  df_cross_tidy = rbind(df_unfair, df_fair)
  
  df_cross_tidy = df_cross_tidy %>% 
    group_by(datatype, tissue, drug, cor_type) %>% 
    summarise(cor = mean(cor, na.rm=T)) %>% 
    group_by(datatype, tissue,drug) %>% 
    mutate(n=n()) %>% 
    filter(n==3) %>% # only include drugs mathched in: Cross, Within, Cross fair
    dplyr::select(-n) %>% 
    ungroup
  
  df_cross_tidy$tissue = firstup(tissue2print(df_cross_tidy$tissue))
  
  # only include matching drugs with Fig 5b
  #df_cross_tidy = df_cross_tidy %>% 
  #  mutate(inFig5b = paste(tissue, drug, sep="===") %in% df_tidy_tissueDrugList) %>% 
  #  filter(inFig5b==TRUE) %>% 
  #  dplyr::select(-inFig5b)
    
  
  df_quantiles = df_cross_tidy %>% group_by(datatype, tissue, cor_type) %>% summarise(q25 = quantile(cor, probs = 0.25), q75=quantile(cor, probs = 0.75))

  df_cross_tidy$cor_type = ordered(df_cross_tidy$cor_type, levels=c("cor_cross", "cor_within", "cor_cross_fair"))
  levels(df_cross_tidy$cor_type) = c("Cross", "Within", "Cross fair")
  
  gg = ggplot(df_cross_tidy, aes(x=tissue, y=cor, fill=cor_type))+
    geom_boxplot(outlier.size=0, outlier.stroke = 0, coef=0, fatten=1)+ # coef=0
    geom_point(size=0.5, alpha=0.3, position = position_jitterdodge(jitter.width = 0.05))+
    ylab("Spearman rank correlation")+
    theme(axis.text.x = element_text(colour = "black",size=size_axes_text,angle=-90,hjust=0,vjust=0.5),
          axis.text.y = element_text(colour = "black",size=size_axes_text),
          axis.title = element_text(size=size_axes_title),
          legend.key = element_blank(),
          panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank(),
          panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"))+
    labs(fill="")+
    coord_cartesian(ylim = c(-0.4, 0.65))+
    scale_fill_manual(values = c('Cross'=CB_PALETTE[5], 'Within'=CB_PALETTE[6], 'Cross fair'=CB_PALETTE[7] ))+
    xlab("")
  
  if(length(unique(df_cross_tidy$datatype))>1)
    gg = gg + facet_grid( datatype ~ .)
  
  return(gg)
}


filename_rppa = "analysis/cross_ccle_rppa.RData"
loadenv = LoadToEnvironment(filename_rppa)
df_rppa_unfair = filter_tissues(loadenv$df)
df_rppa_fair = filter_tissues(loadenv$df_fair)

filename_rnaseq = "analysis/cross_ccle_rnaseq.RData"
loadenv = LoadToEnvironment(filename_rnaseq)
df_rnaseq_unfair = filter_tissues(loadenv$df)
df_rnaseq_fair = filter_tissues(loadenv$df_fair)

df_combined_fair = rbind(df_rppa_fair, df_rnaseq_fair)
df_combined_unfair = rbind(df_rppa_unfair, df_rnaseq_unfair)

df_combined_fair$datatype = gsub("rppa", "Protein", df_combined_fair$datatype)
df_combined_fair$datatype = gsub("rnaseq", "mRNA", df_combined_fair$datatype)
df_combined_unfair$datatype = gsub("rppa", "Protein", df_combined_unfair$datatype)
df_combined_unfair$datatype = gsub("rnaseq", "mRNA", df_combined_unfair$datatype)
gg_ccle_cross_combined = cross_analysis(df_combined_unfair, df_combined_fair)


# PREDICT FROM TUMOR TYPE
#################################

filename = "analysis/analysis_tissuetype.RData"
if(!(file.exists(filename))) {

      out_tissue_ccle = predict_wrapper(dataX=list(datasource="ccle", datatype="tissue"), dataY=list(datasource="ccle", datatype="sen"), match_CLs=list(list(datasource="ccle", datatype="rppa"), list(datasource="ccle", datatype="rnaseq"), list(datasource="ccle", datatype="mut")), Nrep=1, Nbg=0, Ncore=Ncore, method="tissue", return_model = F, remove_dups = remove_dups)
      out_tissue_ctrp = predict_wrapper(dataX=list(datasource="ctrp", datatype="tissue"), dataY=list(datasource="ctrp", datatype="sen"), match_CLs=list(list(datasource="ccle", datatype="rppa"), list(datasource="ccle", datatype="rnaseq"), list(datasource="ccle", datatype="mut")), Nrep=1, Nbg=0, Ncore=Ncore, method="tissue", return_model = F, remove_dups = remove_dups)
      
      df_tissue = data.frame(cor=c(out_tissue_ccle$cors, out_tissue_ctrp$cors ),
                      varExpl=c(out_tissue_ccle$varsExpl, out_tissue_ctrp$varsExpl),
                      drug=c(names(out_tissue_ccle$cors), names(out_tissue_ctrp$cors)),
                      drug_target=c(out_tissue_ccle$drug_targets, out_tissue_ctrp$drug_targets),
                      sen=c(rep("ccle", length(out_tissue_ccle$cors)),rep("ctrp", length(out_tissue_ctrp$cors))))
      
      
      save(df_tissue, file = filename) 
} else {
  loadenv = LoadToEnvironment(filename)
  df_tissue = loadenv$df_tissue
}

# if drug is measured in both ccle and ctrp
# census, then do average cors and varsExpl
senAvgPipe = function(df) {
  df %>% 
    dplyr::select(-drug_target) %>% 
    gather(key="valType", value="val", -(drug:sen)) %>% 
    group_by(drug, valType) %>% 
    summarize(val=mean(val, na.rm=T)) %>% 
    spread(key=valType, value=val)
}

df_mmp = df_vol_complete %>% 
  filter(tissue=="Pan-cancer") %>% 
  dplyr::select(-pval_cor, -pval_varExpl, -tissue) %>% 
  gather(key="valType", value="val", -(datasource:drug_target)) %>%
  group_by(datatype, drug, valType) %>% 
  summarize(val=mean(val, na.rm=T)) %>%
  ungroup %>% 
  spread(key=valType, value=val) %>% 
  group_by(drug) %>% 
  mutate(n=n()) %>% 
  ungroup %>% 
  filter(n==3) %>% 
  dplyr::select(-n)

df_tissue = senAvgPipe(df_tissue)
df_tissue = df_tissue %>% filter(drug %in% df_mmp$drug)

df_tissueVsMmp = rbind(df_mmp, cbind(data.frame(datatype=rep("Tissue", nrow(df_tissue)), df_tissue)))

gg_ccle_pancancer_mmp = ggplot(df_tissueVsMmp, aes(x=datatype, y=cor, fill=datatype))+
  geom_boxplot(outlier.size=0, outlier.stroke = 0, coef=0, fatten=1)+
  geom_point(size=1.0, alpha=0.3, position = position_jitterdodge(jitter.width = 0.10))+
  ylab("Spearman rank correlation")+
  theme(axis.text.x = element_text(colour = "black",size=size_axes_text,angle=-90,hjust=0,vjust=0.5),
        axis.title.x = element_blank(),
        axis.text.y = element_text(colour = "black",size=size_axes_text),
        axis.title = element_text(size=size_axes_title),
        legend.key = element_blank(),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_rect(colour = "black", fill=NA, size=size_panel_border, linetype="solid"))+
  labs(fill="")+
  scale_fill_manual(values = c('mRNA'=CB_PALETTE[1], 'Protein'=CB_PALETTE[2], 'Mutation'=CB_PALETTE[3], 'Tissue'=CB_PALETTE[4] ))


# SI
df_vol_complete_corcor = df_vol_complete %>% 
  filter(matched==TRUE, remove_dups==FALSE) %>% 
  group_by(datatype, tissue, drug) %>% 
  summarise(cor = mean(cor, na.rm=T), varExpl = mean(varExpl, na.rm=T) )

gg_ccle_pancancer_mRNAVSProtein = plot_corcor_scatter(df_vol_complete_corcor, "Protein", "mRNA", color_tissue=T)
gg_ccle_pancancer_tissueVSProtein = plot_corcor_scatter(df_tissueVsMmp, "Protein", "Tissue")
gg_ccle_pancancer_tissueVSmRNA = plot_corcor_scatter(df_tissueVsMmp, "mRNA", "Tissue")
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_pancancer_mRNAVSProtein.pdf", sep=""), gg_ccle_pancancer_mRNAVSProtein, base_height = 4, base_width = 5.2)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_pancancer_tissueVSProtein.pdf", sep=""), gg_ccle_pancancer_tissueVSProtein, base_height = 4, base_width = 4)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_pancancer_tissueVSmRNA.pdf", sep=""), gg_ccle_pancancer_tissueVSmRNA, base_height = 4, base_width = 4)


# COMBINE
#################################

col1 = plot_grid(gg_vol_cor+theme(legend.position = "bottom"), 
                 gg_ccle_pancancer_mmp+theme(legend.position = "none"),
                 ncol=1, rel_heights = c(0.65, 0.35), labels=c("a", "c"))
col2 = plot_grid(gg_mutVsRppaVsRnaseq+theme(legend.position = "bottom", legend.margin=margin(t = -0.5, unit='cm')), 
                 gg_ccle_cross_combined+theme(legend.position = "bottom", legend.margin=margin(t = -0.5, unit='cm')),
                 ncol=1, rel_heights = c(0.5, 0.5), labels=c("b", "d"))
fig5 = plot_grid(NULL, col1, NULL, col2, ncol=4, rel_widths = c(0.05, 1,0.1,1))

save_plot(paste(FIG_PATH, "figure5.pdf", sep=""), fig5, base_width = 7.4, base_height = 7.4)

